@@ -7,7 +7,7 @@ use vars qw($VERSION @ISA);
 # Term::ANSIColor doesn't support STRIKETHROUGH, so we'll do it ourselves.
 use constant STRIKETHROUGH => "\e[9m";
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA = qw(Text::WordDiff::Base);
 
 sub same_items {
@@ -93,9 +93,14 @@ All other content is simply returned.
 
 =back
 
-=head1 Bugs
+=head1 Support
 
-Please send bug reports to <bug-text-worddiff@rt.cpan.org>.
+This module is stored in an open repository at the following address:
+
+L<https://svn.kineticode.com/Text-WordDiff/trunk/>
+
+Patches against SVN::Notify are welcome. Please send bug reports to
+<bug-text-worddiff@rt.cpan.org>.
 
 =head1 Author
 
@@ -112,7 +117,7 @@ David Wheeler <david@kineticode.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2005 Kineticode, Inc. All Rights Reserved.
+Copyright (c) 2005-2008 David Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under the
 same terms as Perl itself.
